primer_designer package
=======================

Submodules
----------

primer_designer.designer module
-------------------------------

.. automodule:: primer_designer.designer
    :members:
    :undoc-members:
    :show-inheritance:

primer_designer.utils module
----------------------------

.. automodule:: primer_designer.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: primer_designer
    :members:
    :undoc-members:
    :show-inheritance:
